==> haskell-data-functor-logistic-0.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-AtjD19Cp8nSqaP8XgPnQC
key:                  data-functor-logistic-0.0-AtjD19Cp8nSqaP8XgPnQC
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  03cf833a1bc459b3dcfc5c5081f0f661
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-AtjD19Cp8nSqaP8XgPnQC
depends:
    base-4.17.2.1 distributive-0.6.2.1-30l18gsEECBGPtCeWB2XoG

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-functor-logistic-0.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-J2EKNfu1mbK5fiONx2gypH
key:                  data-functor-logistic-0.0-J2EKNfu1mbK5fiONx2gypH
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  24b55d247ba41d3443be5cac35dcf459
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-J2EKNfu1mbK5fiONx2gypH
depends:
    base-4.17.2.1 distributive-0.6.2.1-D3SXffd2XIlAT2MovnSdW4

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
